footylib package
================

Submodules
----------

footylib.footylib module
------------------------

.. automodule:: footylib.footylib
    :members:
    :undoc-members:
    :show-inheritance:

footylib.footylibExceptions module
----------------------------------

.. automodule:: footylib.footylibExceptions
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: footylib
    :members:
    :undoc-members:
    :show-inheritance:
